@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef CALENDARSUPPORT_PLUGIN_H
-#define CALENDARSUPPORT_PLUGIN_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -64,4 +63,3 @@ protected:
 };
 }
 
-#endif
