@@ -13,6 +13,8 @@
 #include "kcalprefs.h"
 #include "utils.h"
 
+#include <cmath>
+
 #include <Item>
 
 #include <KCalendarCore/Visitor>
@@ -73,20 +75,20 @@ void CalPrintIncidence::setSettingsWidget()
     }
 }
 
-void CalPrintIncidence::loadConfig()
+void CalPrintIncidence::doLoadConfig()
 {
+    CalPrintPluginBase::doLoadConfig();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
         mShowOptions = grp.readEntry("Show Options", false);
         mShowSubitemsNotes = grp.readEntry("Show Subitems and Notes", false);
         mShowAttendees = grp.readEntry("Use Attendees", false);
         mShowAttachments = grp.readEntry("Use Attachments", false);
-        mShowNoteLines = grp.readEntry("Note Lines", false);
     }
     setSettingsWidget();
 }
 
-void CalPrintIncidence::saveConfig()
+void CalPrintIncidence::doSaveConfig()
 {
     readSettingsWidget();
     if (mConfig) {
@@ -95,8 +97,8 @@ void CalPrintIncidence::saveConfig()
         grp.writeEntry("Show Subitems and Notes", mShowSubitemsNotes);
         grp.writeEntry("Use Attendees", mShowAttendees);
         grp.writeEntry("Use Attachments", mShowAttachments);
-        grp.writeEntry("Note Lines", mShowNoteLines);
     }
+    CalPrintPluginBase::doSaveConfig();
 }
 
 class TimePrintStringsVisitor : public KCalendarCore::Visitor
@@ -632,12 +634,221 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
     p.setFont(oldFont);
 }
 
+/**************************************************************
+ *           Print Timetables
+ **************************************************************/
+
+CalPrintTimetable::CalPrintTimetable()
+    : CalPrintPluginBase()
+{
+}
+
+CalPrintTimetable::~CalPrintTimetable()
+{
+}
+
+void CalPrintTimetable::doLoadConfig()
+{
+    CalPrintPluginBase::doLoadConfig();
+    if (mConfig) {
+        KConfigGroup grp(mConfig, groupName());
+        QDate dt = QDate::currentDate(); // any valid QDate will do
+        QTime tm1(dayStart());
+        QDateTime startTm(dt, tm1);
+        QDateTime endTm(dt, tm1.addSecs(12 * 60 * 60));
+        mStartTime = grp.readEntry("Start time", startTm).time();
+        mEndTime = grp.readEntry("End time", endTm).time();
+        mIncludeDescription = grp.readEntry("Include description", false);
+        mIncludeCategories = grp.readEntry("Include categories", false);
+        mIncludeTodos = grp.readEntry("Include todos", false);
+        mIncludeAllEvents = grp.readEntry("Include all events", false);
+        mSingleLineLimit = grp.readEntry("Single line limit", false);
+        mExcludeTime = grp.readEntry("Exclude time", false);
+    }
+}
+
+void CalPrintTimetable::doSaveConfig()
+{
+    if (mConfig) {
+        KConfigGroup grp(mConfig, groupName());
+        QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
+        dt.setTime(mStartTime);
+        grp.writeEntry("Start time", dt);
+        dt.setTime(mEndTime);
+        grp.writeEntry("End time", dt);
+        grp.writeEntry("Include description", mIncludeDescription);
+        grp.writeEntry("Include categories", mIncludeCategories);
+        grp.writeEntry("Include todos", mIncludeTodos);
+        grp.writeEntry("Include all events", mIncludeAllEvents);
+        grp.writeEntry("Single line limit", mSingleLineLimit);
+        grp.writeEntry("Exclude time", mExcludeTime);
+    }
+    CalPrintPluginBase::doSaveConfig();
+}
+
+static QString cleanString(const QString &instr)
+{
+    QString ret = instr;
+    return ret.replace(QLatin1Char('\n'), QLatin1Char(' '));
+}
+
+void CalPrintTimetable::drawAllDayBox(QPainter &p,
+                                      const KCalendarCore::Event::List &eventList,
+                                      QDate qd,
+                                      QRect box,
+                                      const QList<QDate> &workDays)
+{
+    int lineSpacing = p.fontMetrics().lineSpacing();
+
+    if (!workDays.contains(qd)) {
+        drawShadedBox(p, BOX_BORDER_WIDTH, QColor(232, 232, 232), box);
+    } else {
+        drawBox(p, BOX_BORDER_WIDTH, box);
+    }
+
+    QRect eventBox(box);
+    eventBox.setTop(box.top() + padding());
+    eventBox.setBottom(eventBox.top() + lineSpacing);
+
+    for (const KCalendarCore::Event::Ptr &currEvent : std::as_const(eventList)) {
+        if (!currEvent
+            || !currEvent->allDay()
+            || (mExcludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+            || (mExcludePrivate && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
+            continue;
+        }
+        QString str;
+        if (currEvent->location().isEmpty()) {
+            str = cleanString(currEvent->summary());
+        } else {
+            str = i18nc("summary, location", "%1, %2", cleanString(currEvent->summary()), cleanString(currEvent->location()));
+        }
+        if (mIncludeCategories && !currEvent->categoriesStr().isEmpty()) {
+                str = i18nc("summary, categories", "%1, %2", str, currEvent->categoriesStr());
+        }
+        printEventString(p, eventBox, str);
+        eventBox.setTop(eventBox.bottom());
+        eventBox.setBottom(eventBox.top() + lineSpacing);
+    }
+}
+
+void CalPrintTimetable::drawTimeTable(QPainter &p,
+                                       const QDate &fromDate,
+                                       const QDate &toDate,
+                                       const QRect &box)
+{
+    QTime myFromTime = mStartTime;
+    QTime myToTime = mEndTime;
+    int maxAllDayEvents = 0;
+    QDate curDate(fromDate);
+    while (curDate <= toDate) {
+        KCalendarCore::Event::List eventList = mCalendar->events(curDate, QTimeZone::systemTimeZone());
+        const auto holidays = holiday(curDate);
+        int allDayEvents = holiday(curDate).isEmpty() ? 0 : 1;
+        for (const KCalendarCore::Event::Ptr &event : std::as_const(eventList)) {
+            Q_ASSERT(event);
+            if (!event
+                || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
+                || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
+                continue;
+            }
+            if (event->allDay()) {
+                allDayEvents += 1;
+            } else if (mIncludeAllEvents) {
+                if (event->dtStart().time() < myFromTime) {
+                    myFromTime = event->dtStart().time();
+                }
+                if (event->dtEnd().time() > myToTime) {
+                    myToTime = event->dtEnd().time();
+                }
+            }
+        }
+        if (allDayEvents > maxAllDayEvents) {
+            maxAllDayEvents = allDayEvents;
+        }
+        curDate = curDate.addDays(1);
+    }
+
+    QFont oldFont(p.font());
+    p.setFont(QFont(QStringLiteral("sans-serif"), 11, QFont::Normal));
+    const int lineSpacing = p.fontMetrics().lineSpacing();
+
+    int timelineWidth = TIMELINE_WIDTH + padding();
+
+    QRect dowBox(box);
+    dowBox.setLeft(box.left() + timelineWidth);
+    dowBox.setHeight(mSubHeaderHeight);
+    drawDaysOfWeek(p, fromDate, toDate, dowBox);
+
+    int tlTop = dowBox.bottom();
+
+    int alldayHeight = 0;
+    if (maxAllDayEvents > 0) {
+        // Draw the side bar for all-day events.
+        const auto alldayLabel =  i18nc("label for timetable all-day boxes", "All day");
+        QFont oldFont(p.font());
+        p.setFont(QFont(QStringLiteral("sans-serif"), 9, QFont::Normal));
+        const auto labelHeight = p.fontMetrics().horizontalAdvance(alldayLabel) + 2*padding();
+        alldayHeight = std::max(maxAllDayEvents*lineSpacing + 2*padding(), labelHeight);
+        drawVerticalBox(p,
+                        BOX_BORDER_WIDTH,
+                        QRect(0, tlTop, TIMELINE_WIDTH, alldayHeight),
+                        alldayLabel,
+                        Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap);
+        p.setFont(oldFont);
+        tlTop += alldayHeight +padding();
+    }
+
+    QRect tlBox(box);
+    tlBox.setWidth(TIMELINE_WIDTH);
+    tlBox.setTop(tlTop);
+    drawTimeLine(p, myFromTime, myToTime, tlBox);
+
+    // draw each day
+    curDate = fromDate;
+    int i = 0;
+    double cellWidth = double(dowBox.width() - 1) / double(fromDate.daysTo(toDate) + 1);
+    QRect allDayBox(dowBox.left(), dowBox.bottom(), cellWidth, alldayHeight);
+    const QList<QDate> workDays = CalendarSupport::workDays(fromDate, toDate);
+    while (curDate <= toDate) {
+        KCalendarCore::Event::List eventList =
+            mCalendar->events(curDate, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+
+        allDayBox.setLeft(dowBox.left() + int(i * cellWidth));
+        allDayBox.setRight(dowBox.left() + int((i + 1) * cellWidth));
+        if (maxAllDayEvents > 0) {
+            if (const auto h = holidayEvent(curDate)) {
+                eventList.prepend(h);
+            }
+            drawAllDayBox(p, eventList, curDate, allDayBox, workDays);
+        }
+
+        QRect dayBox(allDayBox);
+        dayBox.setTop(tlTop);
+        dayBox.setBottom(box.bottom());
+        drawAgendaDayBox(p,
+                         eventList,
+                         curDate,
+                         false,
+                         myFromTime,
+                         myToTime,
+                         dayBox,
+                         mIncludeDescription,
+                         mIncludeCategories,
+                         mExcludeTime,
+                         workDays);
+
+        ++i;
+        curDate = curDate.addDays(1);
+    }
+}
+
 /**************************************************************
  *           Print Day
  **************************************************************/
 
 CalPrintDay::CalPrintDay()
-    : CalPrintPluginBase()
+    : CalPrintTimetable()
 {
 }
 
@@ -710,47 +921,24 @@ void CalPrintDay::setSettingsWidget()
     }
 }
 
-void CalPrintDay::loadConfig()
+void CalPrintDay::doLoadConfig()
 {
+    CalPrintTimetable::doLoadConfig();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
-        QDate dt = QDate::currentDate(); // any valid QDate will do
-        QTime tm1(dayStart());
-        QDateTime startTm(dt, tm1);
-        QDateTime endTm(dt, tm1.addSecs(12 * 60 * 60));
-        mStartTime = grp.readEntry("Start time", startTm).time();
-        mEndTime = grp.readEntry("End time", endTm).time();
-        mIncludeDescription = grp.readEntry("Include description", false);
-        mIncludeCategories = grp.readEntry("Include categories", false);
-        mIncludeTodos = grp.readEntry("Include todos", false);
-        mIncludeAllEvents = grp.readEntry("Include all events", false);
         mDayPrintType = static_cast<eDayPrintType>(grp.readEntry("Print type", static_cast<int>(Timetable)));
-        mSingleLineLimit = grp.readEntry("Single line limit", false);
-        mShowNoteLines = grp.readEntry("Note Lines", false);
-        mExcludeTime = grp.readEntry("Exclude time", false);
     }
     setSettingsWidget();
 }
 
-void CalPrintDay::saveConfig()
+void CalPrintDay::doSaveConfig()
 {
     readSettingsWidget();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
-        QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
-        dt.setTime(mStartTime);
-        grp.writeEntry("Start time", dt);
-        dt.setTime(mEndTime);
-        grp.writeEntry("End time", dt);
-        grp.writeEntry("Include description", mIncludeDescription);
-        grp.writeEntry("Include categories", mIncludeCategories);
-        grp.writeEntry("Include todos", mIncludeTodos);
-        grp.writeEntry("Include all events", mIncludeAllEvents);
         grp.writeEntry("Print type", int(mDayPrintType));
-        grp.writeEntry("Single line limit", mSingleLineLimit);
-        grp.writeEntry("Note Lines", mShowNoteLines);
-        grp.writeEntry("Exclude time", mExcludeTime);
     }
+    CalPrintTimetable::doSaveConfig();
 }
 
 void CalPrintDay::setDateRange(const QDate &from, const QDate &to)
@@ -763,6 +951,45 @@ void CalPrintDay::setDateRange(const QDate &from, const QDate &to)
     }
 }
 
+void CalPrintDay::drawDays(QPainter &p, const QRect &box)
+{
+    const int numberOfDays = mFromDate.daysTo(mToDate) + 1;
+    int vcells;
+    const bool portrait = (box.height() > box.width());
+    int cellWidth;
+    if (portrait) {
+        // 2 columns
+        vcells = std::ceil(static_cast<double>(numberOfDays) / 2.0);
+        if (numberOfDays > 1) {
+            cellWidth = box.width() / 2;
+        } else {
+            cellWidth = box.width();
+        }
+    } else {
+        // landscape: N columns
+        vcells = 1;
+        cellWidth = box.width() / numberOfDays;
+    }
+    const int cellHeight = box.height() / vcells;
+    QDate weekDate = mFromDate;
+    for (int i = 0; i < numberOfDays; ++i, weekDate = weekDate.addDays(1)) {
+        const int hpos = i / vcells;
+        const int vpos = i % vcells;
+        const QRect dayBox(box.left() + cellWidth * hpos, box.top() + cellHeight * vpos, cellWidth, cellHeight);
+        drawDayBox(p,
+                   weekDate,
+                   mStartTime,
+                   mEndTime,
+                   dayBox,
+                   true,
+                   true,
+                   true,
+                   mSingleLineLimit,
+                   mIncludeDescription,
+                   mIncludeCategories);
+    } // for i through all selected days
+}
+
 void CalPrintDay::print(QPainter &p, int width, int height)
 {
     QDate curDay(mFromDate);
@@ -789,26 +1016,9 @@ void CalPrintDay::print(QPainter &p, int width, int height)
         }
         drawHeader(p, title, mFromDate, QDate(), headerBox);
         if (mDayPrintType == Filofax) {
-            drawDays(p,
-                     mFromDate,
-                     mToDate,
-                     mStartTime,
-                     mEndTime,
-                     daysBox,
-                     mSingleLineLimit,
-                     mIncludeDescription,
-                     mIncludeCategories);
+            drawDays(p, daysBox);
         } else if (mDayPrintType == SingleTimetable) {
-            drawTimeTable(p,
-                          mFromDate,
-                          mToDate,
-                          mIncludeAllEvents,
-                          mStartTime,
-                          mEndTime,
-                          daysBox,
-                          mIncludeDescription,
-                          mIncludeCategories,
-                          mExcludeTime);
+            drawTimeTable(p, mFromDate, mToDate, daysBox);
         }
         if (mPrintFooter) {
             drawFooter(p, footerBox);
@@ -830,16 +1040,7 @@ void CalPrintDay::print(QPainter &p, int width, int height)
             }
 
             drawHeader(p, local.toString(curDay, QLocale::ShortFormat), curDay, QDate(), headerBox);
-            drawTimeTable(p,
-                          curDay,
-                          curDay,
-                          mIncludeAllEvents,
-                          mStartTime,
-                          mEndTime,
-                          daysBox,
-                          mIncludeDescription,
-                          mIncludeCategories,
-                          mExcludeTime);
+            drawTimeTable(p, curDay, curDay, daysBox);
             if (mPrintFooter) {
                 drawFooter(p, footerBox);
             }
@@ -857,7 +1058,7 @@ void CalPrintDay::print(QPainter &p, int width, int height)
  **************************************************************/
 
 CalPrintWeek::CalPrintWeek()
-    : CalPrintPluginBase()
+    : CalPrintTimetable()
 {
 }
 
@@ -930,49 +1131,27 @@ void CalPrintWeek::setSettingsWidget()
         cfg->mExcludeConfidential->setChecked(mExcludeConfidential);
         cfg->mExcludePrivate->setChecked(mExcludePrivate);
     }
+    CalPrintTimetable::setSettingsWidget();
 }
 
-void CalPrintWeek::loadConfig()
+void CalPrintWeek::doLoadConfig()
 {
+    CalPrintTimetable::doLoadConfig();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
-        QDate dt = QDate::currentDate(); // any valid QDate will do
-        QTime tm1(dayStart());
-        QDateTime startTm(dt, tm1);
-        QDateTime endTm(dt, tm1.addSecs(43200));
-        mStartTime = grp.readEntry("Start time", startTm).time();
-        mEndTime = grp.readEntry("End time", endTm).time();
-        mShowNoteLines = grp.readEntry("Note Lines", false);
-        mSingleLineLimit = grp.readEntry("Single line limit", false);
-        mIncludeTodos = grp.readEntry("Include todos", false);
-        mIncludeAllEvents = grp.readEntry("Include all events", false);
         mWeekPrintType = (eWeekPrintType)(grp.readEntry("Print type", (int)Filofax));
-        mIncludeDescription = grp.readEntry("Include Description", false);
-        mIncludeCategories = grp.readEntry("Include categories", false);
-        mExcludeTime = grp.readEntry("Exclude Time", false);
     }
     setSettingsWidget();
 }
 
-void CalPrintWeek::saveConfig()
+void CalPrintWeek::doSaveConfig()
 {
     readSettingsWidget();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
-        QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
-        dt.setTime(mStartTime);
-        grp.writeEntry("Start time", dt);
-        dt.setTime(mEndTime);
-        grp.writeEntry("End time", dt);
-        grp.writeEntry("Note Lines", mShowNoteLines);
-        grp.writeEntry("Single line limit", mSingleLineLimit);
-        grp.writeEntry("Include todos", mIncludeTodos);
-        grp.writeEntry("Include all events", mIncludeAllEvents);
         grp.writeEntry("Print type", int(mWeekPrintType));
-        grp.writeEntry("Include Description", mIncludeDescription);
-        grp.writeEntry("Include categories", mIncludeCategories);
-        grp.writeEntry("Exclude Time", mExcludeTime);
     }
+    CalPrintTimetable::doSaveConfig();
 }
 
 QPageLayout::Orientation CalPrintWeek::defaultOrientation() const
@@ -996,6 +1175,49 @@ void CalPrintWeek::setDateRange(const QDate &from, const QDate &to)
     }
 }
 
+void CalPrintWeek::drawWeek(QPainter &p,
+                                  const QDate &qd,
+                                  const QRect &box)
+{
+    QDate weekDate = qd;
+    const bool portrait = (box.height() > box.width());
+    int cellWidth;
+    int vcells;
+    if (portrait) {
+        cellWidth = box.width() / 2;
+        vcells = 3;
+    } else {
+        cellWidth = box.width() / 6;
+        vcells = 1;
+    }
+    const int cellHeight = box.height() / vcells;
+
+    // correct begin of week
+    int weekdayCol = weekdayColumn(qd.dayOfWeek());
+    weekDate = qd.addDays(-weekdayCol);
+
+    for (int i = 0; i < 7; ++i, weekDate = weekDate.addDays(1)) {
+        // Saturday and sunday share a cell, so we have to special-case sunday
+        int hpos = ((i < 6) ? i : (i - 1)) / vcells;
+        int vpos = ((i < 6) ? i : (i - 1)) % vcells;
+        QRect dayBox(box.left() + cellWidth * hpos,
+                     box.top() + cellHeight * vpos + ((i == 6) ? (cellHeight / 2) : 0),
+                     cellWidth,
+                     (i < 5) ? (cellHeight) : (cellHeight / 2));
+        drawDayBox(p,
+                   weekDate,
+                   mStartTime,
+                   mEndTime,
+                   dayBox,
+                   true,
+                   true,
+                   true,
+                   mSingleLineLimit,
+                   mIncludeDescription,
+                   mIncludeCategories);
+    } // for i through all weekdays
+}
+
 void CalPrintWeek::print(QPainter &p, int width, int height)
 {
     QDate curWeek, fromWeek, toWeek;
@@ -1026,8 +1248,7 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
             title =  i18nc("date from-to", "%1\u2013%2", line1, line2);
             drawHeader(p, title, curWeek.addDays(-6), QDate(), headerBox);
 
-            drawWeek(p, curWeek, mStartTime, mEndTime, weekBox, mSingleLineLimit,
-                      mIncludeDescription, mIncludeCategories);
+            drawWeek(p, curWeek, weekBox);
 
             if (mPrintFooter) {
                 drawFooter(p, footerBox);
@@ -1052,8 +1273,7 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
             }
             drawHeader(p, title, curWeek, QDate(), headerBox);
 
-            drawTimeTable(p, fromWeek, curWeek, mIncludeAllEvents, mStartTime, mEndTime, weekBox, mIncludeDescription,
-                           mIncludeCategories, mExcludeTime);
+            drawTimeTable(p, fromWeek, curWeek, weekBox);
 
             if (mPrintFooter) {
                 drawFooter(p, footerBox);
@@ -1078,23 +1298,13 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
             int hh = headerHeight();
 
             drawSplitHeaderRight(p, fromWeek, curWeek, QDate(), width, hh);
-            drawTimeTable(p, fromWeek, endLeft, mIncludeAllEvents, mStartTime, mEndTime, weekBox, mIncludeDescription,
-                           mIncludeCategories, mExcludeTime);
+            drawTimeTable(p, fromWeek, endLeft, weekBox);
             if (mPrintFooter) {
                 drawFooter(p, footerBox);
             }
             mPrinter->newPage();
             drawSplitHeaderRight(p, fromWeek, curWeek, QDate(), width, hh);
-            drawTimeTable(p,
-                          endLeft.addDays(1),
-                          curWeek,
-                          mIncludeAllEvents,
-                          mStartTime,
-                          mEndTime,
-                          weekBox1,
-                          mIncludeDescription,
-                          mIncludeCategories,
-                          mExcludeTime);
+            drawTimeTable(p, endLeft.addDays(1), curWeek, weekBox1);
 
             if (mPrintFooter) {
                 drawFooter(p, footerBox);
@@ -1174,8 +1384,9 @@ void CalPrintMonth::setSettingsWidget()
     }
 }
 
-void CalPrintMonth::loadConfig()
+void CalPrintMonth::doLoadConfig()
 {
+    CalPrintPluginBase::doLoadConfig();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
         mWeekNumbers = grp.readEntry("Print week numbers", true);
@@ -1183,14 +1394,13 @@ void CalPrintMonth::loadConfig()
         mRecurWeekly = grp.readEntry("Print weekly incidences", true);
         mIncludeTodos = grp.readEntry("Include todos", false);
         mSingleLineLimit = grp.readEntry("Single line limit", false);
-        mShowNoteLines = grp.readEntry("Note Lines", false);
         mIncludeDescription = grp.readEntry("Include description", false);
         mIncludeCategories = grp.readEntry("Include categories", false);
     }
     setSettingsWidget();
 }
 
-void CalPrintMonth::saveConfig()
+void CalPrintMonth::doSaveConfig()
 {
     readSettingsWidget();
     if (mConfig) {
@@ -1200,10 +1410,10 @@ void CalPrintMonth::saveConfig()
         grp.writeEntry("Print weekly incidences", mRecurWeekly);
         grp.writeEntry("Include todos", mIncludeTodos);
         grp.writeEntry("Single line limit", mSingleLineLimit);
-        grp.writeEntry("Note Lines", mShowNoteLines);
         grp.writeEntry("Include description", mIncludeDescription);
         grp.writeEntry("Include categories", mIncludeCategories);
     }
+    CalPrintPluginBase::doSaveConfig();
 }
 
 void CalPrintMonth::setDateRange(const QDate &from, const QDate &to)
@@ -1376,8 +1586,9 @@ void CalPrintTodos::setSettingsWidget()
     }
 }
 
-void CalPrintTodos::loadConfig()
+void CalPrintTodos::doLoadConfig()
 {
+    CalPrintPluginBase::doLoadConfig();
     if (mConfig) {
         KConfigGroup grp(mConfig, groupName());
         mPageTitle = grp.readEntry("Page title", i18n("To-do list"));
@@ -1396,7 +1607,7 @@ void CalPrintTodos::loadConfig()
     setSettingsWidget();
 }
 
-void CalPrintTodos::saveConfig()
+void CalPrintTodos::doSaveConfig()
 {
     readSettingsWidget();
     if (mConfig) {
@@ -1414,6 +1625,7 @@ void CalPrintTodos::saveConfig()
         grp.writeEntry("Sort field", static_cast<int>(mTodoSortField));
         grp.writeEntry("Sort direction", static_cast<int>(mTodoSortDirection));
     }
+    CalPrintPluginBase::doSaveConfig();
 }
 
 void CalPrintTodos::print(QPainter &p, int width, int height)
